/***********************************************************************
	CommAnalyzerMain.c
	
	Created:	Wednesday, April 21, 1993, 11:26 AM
	Project:	CommAnalyzer.
	Compiler:	6.0,  Symantec Corporation 1993
	By:			Greg Ames

	Copyright  1993,1993 Ames & Associates.
	All rights reserved. 

	AppleLink:AMES
	AOL:AMES
	Compuserve:73177,1603

***********************************************************************/

#include <STDLib.h>
#include <Serial.h>

#include "CommAnalyzerMenus.h"
#include "CommAnalyzerWindow.h"
#include "CommAnalyzer.h"

//***********************************************************************/

#define kBufSize	0x3000
#define baud38400	1						// the define that apple forgot

extern	WindowPtr	bullseyeWindow;
extern	Rect		dragRect;
short	ain,bin,aout,bout;
char	abuffer[kBufSize],bbuffer[kBufSize];

void InitMacintosh(void);
void HandleMouseDown (EventRecord	*theEvent);
void HandleEvent(void);
void idleAnalyser(void);

/****
 * InitMacintosh()
 *
 * Initialize all the managers & memory
 *
 ****/

void InitMacintosh(void)

{
	MaxApplZone();
	
	InitGraf(&thePort);
	InitFonts();
	FlushEvents(everyEvent, 0);
	InitWindows();
	InitMenus();
	TEInit();
	InitDialogs(0L);
	InitCursor();

}
/* end InitMacintosh */


/****
 * HandleMouseDown (theEvent)
 *
 *	Take care of mouseDown events.
 *
 ****/

void HandleMouseDown (EventRecord	*theEvent)

{
	WindowPtr	theWindow;
	int			windowCode = FindWindow (theEvent->where, &theWindow);
	
    switch (windowCode)
      {
	  case inSysWindow: 
	    SystemClick (theEvent, theWindow);
	    break;
	    
	  case inMenuBar:
	  	AdjustMenus();
	    HandleMenu(MenuSelect(theEvent->where));
	    break;
	    
	  case inDrag:
	  	if (theWindow == bullseyeWindow)
	  	  DragWindow(bullseyeWindow, theEvent->where, &dragRect);
	  	  break;
	  	  
	  case inContent:
	  	if (theWindow == bullseyeWindow)
	  	  {
	  	  if (theWindow != FrontWindow())
	  	    SelectWindow(bullseyeWindow);
	  	  else
	  	    InvalRect(&bullseyeWindow->portRect);
	  	  }
	  	break;
	  	
	  case inGoAway:
	  	if (theWindow == bullseyeWindow && 
	  		TrackGoAway(bullseyeWindow, theEvent->where))
		  HideWindow(bullseyeWindow);
	  	  break;
      }
}
/* end HandleMouseDown */


/****
 * HandleEvent()
 *
 *		The main event dispatcher. This routine should be called
 *		repeatedly (it  handles only one event).
 *
 *****/

void HandleEvent(void)

{
	int			ok;
	EventRecord	theEvent;

	HiliteMenu(0);
	SystemTask ();		/* Handle desk accessories */
	
	ok = GetNextEvent (everyEvent, &theEvent);
	if (ok)
	  switch (theEvent.what)
	    {
		case mouseDown:
			HandleMouseDown(&theEvent);
			break;
			
		case keyDown: 
		case autoKey:
		    if ((theEvent.modifiers & cmdKey) != 0)
		      {
		      AdjustMenus();
			  HandleMenu(MenuKey((char) (theEvent.message & charCodeMask)));
			  }
			break;
			
		case updateEvt:
			BeginUpdate(bullseyeWindow);
			DrawBullseye(((WindowPeek) bullseyeWindow)->hilited);
			EndUpdate(bullseyeWindow);
		    break;
		    
		case activateEvt:
			InvalRect(&bullseyeWindow->portRect);
			break;
	    }
}
/* end HandleEvent */


/*****
 * main()
 *
 *	This is where everything happens
 *
 *****/

void	closeSerial(void);

void
main( void)

{
	short	err,doWhat,fileCnt;
	
	InitMacintosh();
	SetUpMenus();
	SetUpWindow();
	
	err = OpenDriver("\p.aout",&aout);
	err = OpenDriver("\p.bout",&bout);

	err = OpenDriver("\p.ain",&ain);
	err = OpenDriver("\p.bin",&bin);
	
	err = SerReset(aout,baud38400+stop10+noParity+data8);
	err = SerReset(ain,baud38400+stop10+noParity+data8);
	err = SerReset(bout,baud38400+stop10+noParity+data8);
	err = SerReset(bin,baud38400+stop10+noParity+data8);

	err = SerSetBuf(ain,(Ptr)&abuffer,kBufSize);
	err = SerSetBuf(bin,(Ptr)&bbuffer,kBufSize);
	

	_atexit(closeSerial);							// make sure the serial ports are closed
	
	CountAppFiles ( &doWhat, &fileCnt );
	if ( doWhat==appOpen )							// double clicked doc from finder
	{
		AppFile	fileStuff;
		GetAppFiles ( 1, &fileStuff );
		openFile(fileStuff);
	}
	
	for (;;)
	{
		idleAnalyser();
		HandleEvent();
	}
}
/* end main */

//***********************************************************************/

void	closeSerial()
{
	short	err;
	
	err = CloseDriver(ain);
	err = CloseDriver(bin);
	err = CloseDriver(aout);
	err = CloseDriver(bout);
}

//***********************************************************************/
